/** 
 @name SequenceLayersSimple
 
 modified by BRYAB so that it simply takes a bunch of layers, cuts them to one frame, and then sequences them in order.
 
original author info:
Charles Bordenave
http://www.nabscripts.com/downloads/scripts/SequenceLayers.zip

*/


/**
 This class represents the main class of the script;s
 it is used to create the user interface which allows to sequences the selected layers from the current composition time, 
 by offsetting their inpoint 
 @class Main class of the script
*/
function SequenceLayers()
{
    // Variable used to keep track of 'this' reference
    var sequenceLayers = this;
    
    // Create an instance of the utils class to use its functions
   // var utils = new SequenceLayersUtils();

    // Script infos
    this.scriptMinSupportVersion = "8.0";
    this.scriptName = "SequenceLayers.jsx";    
    this.scriptVersion = "2.0";
    this.scriptTitle = "Sequence Layers";
    
    
    /**
     Determines whether the active item is a composition  
     @return True if the active item is not a composition, False otherwise
    */    
    this.checkActiveItem = function () 
    {
        var err = false;
        var comp = app.project.activeItem;
        if (!comp || !(comp instanceof CompItem))
        {
            err = true;
        }
        return err;
    };
    
    /**
     Functional part of the script: sequences the selected layers by offsetting their inpoints
     @param {Object} pal A palette or a dockable panel containing all user parameters          
    */    
    this.sequence = function ()
    {
        try
        {
            var comp = app.project.activeItem;
            var err = this.noCompErr;
            if (this.checkActiveItem(comp)) throw(err);
                    
            var selLayers = comp.selectedLayers;
            var err = this.noLayersErr;
            if (selLayers.length < 1) throw(err);
            
            var offset = 1* comp.frameDuration;
            
            app.beginUndoGroup(this.scriptTitle);
                  
            for (var i = 0; i < selLayers.length; i++) {
				selLayers[i].outPoint = offset;
				selLayers[i].startTime = comp.time + i * offset;
				}
                  
            app.endUndoGroup();
        }
        catch(err)
        {
            utils.throwErr(err);
        }                
    };
    
    /**
     Runs the script  
     @param {Object} thisObj A Panel object if the script is launched from the Window menu, null otherwise
    */
    this.run = function (thisObj) 
    {
		sequenceLayers.sequence();
    };
}

/**
 Creates an instance of the main class and run it
*/
new SequenceLayers().run(this);
